# ktch.datasets

```{eval-rst}
.. automodule:: ktch.datasets
   :no-members:
   :no-inherited-members:
```

## Functions

```{eval-rst}
.. currentmodule:: ktch

.. autosummary::
   :toctree: generated/
   :template: base.rst

   datasets.load_landmark_mosquito_wings
   datasets.load_landmark_trilobite_cephala
   datasets.load_outline_mosquito_wings
   datasets.load_outline_leaf_bending
   datasets.load_image_passiflora_leaves
   datasets.convert_coords_df_to_list
   datasets.convert_coords_df_to_df_sklearn_transform
   datasets.make_landmarks_from_reference
```
